Module evaluation

Module evaluation 

Alignment quality evaluation metrics.

Provides functions for measuring the quality of a network alignment, including edge conservation, symmetric substructure score, node correctness, and induced conserved structure.

Functions

edge_conservation
Edge Conservation (EC): fraction of edges in G1 preserved in the mapping to G2.
induced_conserved_structure
Induced Conserved Structure (ICS).
node_correctness
Node Correctness (NC): fraction of correctly mapped nodes.
symmetric_substructure_score
Symmetric Substructure Score (S3).