Module base

Module base 

Base graph structures and operations

This module provides the core graph data structures and interfaces for representing and working with graphs.

Re-exports

pub use graph::Graph;
pub use types::Edge;
pub use types::EdgeWeight;
pub use types::Node;

Modules

graph
Basic undirected graph implementation
types
Core types for graph structures

Structs

BipartiteGraph
A bipartite graph structure
DiGraph
A directed graph structure
Hyperedge
Represents a hyperedge in a hypergraph
Hypergraph
A hypergraph structure
MultiDiGraph
A directed multigraph structure
MultiGraph
A multigraph structure (allows multiple edges between same nodes)

Traits

IndexType
Trait for the unsigned integer type used for node and edge indices.