pub struct CsrGraphBuilder { /* private fields */ }Expand description
Builder for constructing CSR graphs from edge lists.
Accumulates edges and then performs a single sort + prefix-sum to build the CSR arrays efficiently.
Implementations
Sourceimpl CsrGraphBuilder
impl CsrGraphBuilder
Sourcepub fn new(num_nodes: usize, directed: bool) -> Self
pub fn new(num_nodes: usize, directed: bool) -> Self
Create a new CSR graph builder.
Arguments
num_nodes- Number of nodes in the graphdirected- Whether the graph is directed
Sourcepub fn with_capacity(
num_nodes: usize,
edge_capacity: usize,
directed: bool,
) -> Self
pub fn with_capacity( num_nodes: usize, edge_capacity: usize, directed: bool, ) -> Self
Create a builder with pre-allocated edge capacity.
Sourcepub fn add_edge(&mut self, src: usize, dst: usize, weight: f64) -> Result<()>
pub fn add_edge(&mut self, src: usize, dst: usize, weight: f64) -> Result<()>
Add a single edge.
For undirected graphs, the reverse edge is added automatically during build.
Sourcepub fn add_unweighted_edge(&mut self, src: usize, dst: usize) -> Result<()>
pub fn add_unweighted_edge(&mut self, src: usize, dst: usize) -> Result<()>
Add an unweighted edge (weight = 1.0).
Sourcepub fn add_edges<I>(&mut self, edges: I) -> Result<()>
pub fn add_edges<I>(&mut self, edges: I) -> Result<()>
Add edges from an iterator of (src, dst, weight) triples.
Sourcepub fn build_parallel(self) -> Result<CsrGraph>
pub fn build_parallel(self) -> Result<CsrGraph>
Build the CSR graph using parallel sorting and construction.