RRSet

Type Alias RRSet 

pub type RRSet = Vec<usize>;
A Reverse Reachable (RR) set: the set of nodes that could activate a randomly chosen target node v in a sampled IC-model graph.

Each entry is a node id in the RR set.

Aliased Type

pub struct RRSet { /* private fields */ }