Module temporal_path

Module temporal_path 

Temporal path finding: earliest arrival, latest departure, and fastest paths.

Edges are represented as (src, dst, departure_time, travel_time) tuples so that the departure from a node can be no earlier than the current arrival time at that node (i.e. time-respecting paths).

Structs

TemporalDijkstra
Dijkstra-style algorithms adapted for temporal (time-respecting) paths.
TemporalPath
A temporal path: a sequence of time-stamped hops through a graph.