pub struct SpectralEmbedding<N: Node> { /* private fields */ }Expand description
Spectral embedding of a graph
Computes a low-dimensional embedding by finding the smallest eigenvectors of the graph Laplacian matrix using the power iteration / inverse iteration method.
Implementations
Sourceimpl<N: Node + Debug> SpectralEmbedding<N>
impl<N: Node + Debug> SpectralEmbedding<N>
Sourcepub fn new(config: SpectralEmbeddingConfig) -> Self
pub fn new(config: SpectralEmbeddingConfig) -> Self
Create a new spectral embedding with the given configuration
Sourcepub fn fit<E, Ix>(&mut self, graph: &Graph<N, E, Ix>) -> Result<()>
pub fn fit<E, Ix>(&mut self, graph: &Graph<N, E, Ix>) -> Result<()>
Fit the spectral embedding to a graph
Sourcepub fn get_embedding(&self, node: &N) -> Result<Embedding>
pub fn get_embedding(&self, node: &N) -> Result<Embedding>
Get the embedding for a specific node
Sourcepub fn embeddings(&self) -> Result<HashMap<N, Embedding>>where
N: Clone,
pub fn embeddings(&self) -> Result<HashMap<N, Embedding>>where
N: Clone,
Get all embeddings as a HashMap
Sourcepub fn embedding_matrix(&self) -> Result<&Array2<f64>>
pub fn embedding_matrix(&self) -> Result<&Array2<f64>>
Get the embedding matrix (n x d)
Sourcepub fn eigenvalues(&self) -> Result<&Array1<f64>>
pub fn eigenvalues(&self) -> Result<&Array1<f64>>
Get the eigenvalues corresponding to the embedding dimensions
Sourcepub fn dimensions(&self) -> usize
pub fn dimensions(&self) -> usize
Get the embedding dimension
Sourcepub fn pairwise_distances(&self) -> Result<Array2<f64>>
pub fn pairwise_distances(&self) -> Result<Array2<f64>>
Compute pairwise distances between all embedded nodes