Module flow

Module flow 

Standalone network flow algorithms (integer-capacity, index-based API).

This module provides high-performance, standalone flow algorithms that operate on integer capacities and node indices rather than the generic Graph type. They are used internally by other modules (e.g. hypergraph connectivity) and can be used directly for competitive-programming-style graph problems.

Algorithms

Modules

max_flow
Maximum flow algorithms
min_cost_flow
Minimum cost flow algorithms