pub struct EdgeEncoding {
pub edge_embed: Array2<f64>,
pub projection: Array1<f64>,
pub max_edge_types: usize,
pub hidden_dim: usize,
}Expand description
Edge encoding along shortest paths between node pairs.
For each pair (i, j), takes the edges along the shortest path from i to j
and averages the learnable edge embeddings. This provides additional structural
information to the attention mechanism.
Fields
edge_embed: Array2<f64>Learnable edge embedding: [max_edge_types, hidden_dim]
projection: Array1<f64>Projection from hidden_dim to scalar bias
max_edge_types: usizeMaximum number of edge types
Hidden dimension for edge embedding
Implementations
Sourceimpl EdgeEncoding
impl EdgeEncoding
Sourcepub fn new(max_edge_types: usize, hidden_dim: usize) -> Self
pub fn new(max_edge_types: usize, hidden_dim: usize) -> Self
Create a new edge encoding module.
Arguments
max_edge_types- Maximum number of distinct edge feature typeshidden_dim- Dimension for edge embeddings
Sourcepub fn forward(&self, adj: &CsrMatrix, spd: &Array2<usize>) -> Array2<f64>
pub fn forward(&self, adj: &CsrMatrix, spd: &Array2<usize>) -> Array2<f64>
Compute edge bias matrix.
For simplicity, uses edge weights discretized to integer types. Each edge on the shortest path contributes its embedding, which is averaged and projected to a scalar.
Arguments
adj- Adjacency matrix with edge weightsspd- Shortest path distance matrix fromSpatialEncoding::compute_spd_matrix
Returns
Edge bias matrix [n, n]