betweenness_centrality

Function betweenness_centrality 

pub fn betweenness_centrality(hg: &IndexedHypergraph) -> Vec<f64>
Compute hypergraph betweenness centrality for every node.

We compute betweenness on the clique-expansion graph (2-section), where edge weights are used as distances in Dijkstra’s algorithm. The betweenness of node v is the fraction of shortest paths between all pairs (s, t) (s ≠ v ≠ t) that pass through v.

Returns a vector of length n_nodes.