line_graph

Function line_graph 

pub fn line_graph(hg: &IndexedHypergraph) -> Graph<usize, f64>
Build the line graph of an IndexedHypergraph.

Each hyperedge becomes a node. Two hyperedge-nodes are connected iff their corresponding hyperedges share at least one node; the edge weight equals the number of shared nodes.