#[non_exhaustive]pub enum PartitionMethod {
SpectralBisection,
MultilevelKL,
Streaming,
}Expand description
Method used for graph partitioning.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SpectralBisection
Spectral bisection via Fiedler vector of the graph Laplacian.
MultilevelKL
METIS-style multilevel partitioning with Kernighan-Lin refinement.
Streaming
Linear Deterministic Greedy streaming partitioner for very large graphs.