Module sampling

Module sampling 

Graph Sampling Algorithms

This module provides a comprehensive suite of graph sampling methods including:

  • Random walks: Uniform random walk, Node2Vec biased random walk
  • Graph sampling: Frontier sampling, forest-fire sampling, snowball sampling
  • Subgraph operations: Induced subgraph extraction

All algorithms operate on adjacency-list representations for efficiency.

References

  • Leskovec & Faloutsos (2006): Sampling from Large Graphs. KDD 2006.
  • Grover & Leskovec (2016): node2vec: Scalable Feature Learning for Networks. KDD 2016.
  • Stumpf et al. (2005): Subnets of scale-free networks are not scale-free. PNAS.

Functions

forest_fire_sampling
Forest-fire graph sampling.
frontier_sampling
Frontier-based graph sampling.
induced_subgraph
Extract the induced subgraph on a set of nodes.
node2vec_walk
Perform a Node2Vec biased random walk on a weighted graph.
random_walk
Perform a uniform random walk on an unweighted graph.
snowball_sampling
Snowball (BFS-neighbourhood) sampling.