pub struct SimdTraversal;Expand description
SIMD-accelerated operations for BFS/DFS distance and level vectors.
Provides optimized initialization, update, and reduction operations on the distance/level arrays used in graph traversals.
Implementations
Sourceimpl SimdTraversal
impl SimdTraversal
Sourcepub fn relax_neighbors(
distances: &mut Array1<f64>,
adjacency_row: &ArrayView1<'_, f64>,
current_distance: f64,
) -> Vec<usize>
pub fn relax_neighbors( distances: &mut Array1<f64>, adjacency_row: &ArrayView1<'_, f64>, current_distance: f64, ) -> Vec<usize>
SIMD-accelerated BFS frontier relaxation.
For each node in the current frontier, attempts to relax the distance of its neighbors. This is the inner loop of BFS.
Arguments
distances- Current distance vector (modified in place)adjacency_row- Adjacency row for the current nodecurrent_distance- Distance of the current node
Returns
Vector of neighbor indices that were relaxed (for the next frontier).
Sourcepub fn eccentricity(distances: &ArrayView1<'_, f64>) -> f64
pub fn eccentricity(distances: &ArrayView1<'_, f64>) -> f64
Sourcepub fn count_reachable(distances: &ArrayView1<'_, f64>) -> usize
pub fn count_reachable(distances: &ArrayView1<'_, f64>) -> usize
Sourcepub fn sum_finite_distances(distances: &ArrayView1<'_, f64>) -> f64
pub fn sum_finite_distances(distances: &ArrayView1<'_, f64>) -> f64
Sourcepub fn element_wise_min(
a: &ArrayView1<'_, f64>,
b: &ArrayView1<'_, f64>,
) -> Array1<f64>
pub fn element_wise_min( a: &ArrayView1<'_, f64>, b: &ArrayView1<'_, f64>, ) -> Array1<f64>
Sourcepub fn diameter_from_distance_matrix(
distance_matrix: &ArrayView2<'_, f64>,
) -> f64
pub fn diameter_from_distance_matrix( distance_matrix: &ArrayView2<'_, f64>, ) -> f64