pub struct GraphMaeConfig {
pub mask_rate: f64,
pub encoder_dim: usize,
pub decoder_dim: usize,
pub replace_token_scale: f64,
}Expand description
Configuration for the Graph Masked Autoencoder.
Fields
mask_rate: f64Fraction of nodes whose features are masked during training.
encoder_dim: usizeEncoder output (latent) dimension.
decoder_dim: usizeDecoder output dimension (must equal the input feature dimension).
replace_token_scale: f64Scale of the random initialisation for the mask replacement token.