pub struct NodeMaskingConfig {
pub mask_rate: f64,
pub replace_rate: f64,
pub n_neighbors: usize,
pub feature_dim: usize,
}Expand description
Configuration for BERT-style node attribute masking.
Fields
mask_rate: f64Fraction of nodes to mask. Default 0.15.
replace_rate: f64Of the masked nodes, fraction replaced with a random feature vector instead of a zero mask vector. Default 0.1.
n_neighbors: usizeNumber of BFS hops used for context features (informational only). Default 2.
feature_dim: usizeFeature dimensionality. Default 64.