pub struct StreamingUnionFind { /* private fields */ }Expand description
Online connected-components via path-compressed, union-by-rank Union-Find.
As edges arrive from the stream the structure is updated in O(α(n)) amortised time per edge (inverse Ackermann).
Implementations
Sourceimpl StreamingUnionFind
impl StreamingUnionFind
Sourcepub fn find(&mut self, x: usize) -> usize
pub fn find(&mut self, x: usize) -> usize
Find the representative of x with full path compression (iterative).
Sourcepub fn process_edge(&mut self, u: usize, v: usize)
pub fn process_edge(&mut self, u: usize, v: usize)
Process edge (u, v) — union the two components.
Sourcepub fn n_components(&self) -> usize
pub fn n_components(&self) -> usize
Return the number of distinct connected components.
Sourcepub fn component_id(&mut self, x: usize) -> usize
pub fn component_id(&mut self, x: usize) -> usize
Return the canonical component identifier for x.