pub struct MemoryBoundedProcessor { /* private fields */ }Expand description
A memory-bounded stream processor that enforces a memory budget.
Processes edge events and maintains approximate graph statistics while staying within a configurable memory limit.
Implementations
Sourceimpl MemoryBoundedProcessor
impl MemoryBoundedProcessor
Sourcepub fn new(config: MemoryBoundedConfig) -> Self
pub fn new(config: MemoryBoundedConfig) -> Self
Create a new memory-bounded processor.
Sourcepub fn process_edge(&mut self, src: usize, dst: usize, weight: f64)
pub fn process_edge(&mut self, src: usize, dst: usize, weight: f64)
Process an edge event, evicting old edges if memory budget is exceeded.
Sourcepub fn graph(&self) -> &StreamingGraph
pub fn graph(&self) -> &StreamingGraph
Get the current streaming graph.
Sourcepub fn edges_evicted(&self) -> u64
pub fn edges_evicted(&self) -> u64
Get the number of edges evicted.
Sourcepub fn estimated_memory(&self) -> usize
pub fn estimated_memory(&self) -> usize
Get estimated memory usage in bytes.
Sourcepub fn degree_distribution(&self) -> DegreeDistribution
pub fn degree_distribution(&self) -> DegreeDistribution
Get the degree distribution of the current graph.