pub fn forest_graph<R: Rng>(
_tree_sizes: &[usize],
sizes: &[usize],
rng: &mut R,
) -> Result<Graph<usize, f64>>Expand description
Generates a random forest (collection of trees)
Creates a forest by generating multiple random trees and combining them into a single graph. The trees are disjoint (no edges between different trees).
Arguments
tree_sizes- Vector specifying the size of each tree in the forestrng- Random number generator
Returns
Result<Graph<usize, f64>>- A forest containing the specified trees