Hypergraph algorithms.
Implements:
- Spectral clustering via the normalised Laplacian (Zhou et al. 2006).
- Hyperedge cuts: raw cut, ratio cut, normalised cut.
- Generalised random walk (Markov chain on nodes through hyperedges).
- Hypergraph betweenness centrality based on shortest paths through the clique-expansion graph.
- s-walks and s-paths: walks/paths between hyperedges that share ≥ s nodes.
Structs
- CutResult
- Result of a hyperedge cut computation.
- Spectral
Clustering Result - Result of hypergraph spectral clustering.
Functions
- betweenness_
centrality - Compute hypergraph betweenness centrality for every node.
- hyperedge_
cut - Compute the hyperedge cut, ratio cut, and normalised cut for a binary partition of the node set.
- s_
betweenness_ centrality - Hyperedge betweenness centrality in the s-line graph.
- s_
diameter - Compute the s-diameter of the hypergraph: the maximum s-distance over all pairs of hyperedges in the same s-connected component.
- s_
distance - Compute the s-distance between two hyperedges: the length of the
shortest s-path (sequence of hyperedges each sharing ≥
snodes with the next). - s_
reachability - Enumerate all s-paths of length ≤
max_lenstarting from hyperedgestartas BFS layers. - spectral_
clustering - Perform spectral clustering on a hypergraph using the normalised Laplacian (Zhou et al. NeurIPS 2006).
- stationary_
distribution - Compute the stationary distribution of the generalised random walk on a hypergraph, using power iteration on the transition matrix.