pub trait GraphFilter {
// Required methods
fn apply(
&self,
gft: &GraphFourierTransform,
signal: &Array1<f64>,
) -> Result<Array1<f64>>;
fn frequency_response(&self, gft: &GraphFourierTransform) -> Array1<f64>;
}Expand description
Trait for spectral graph filters.
A filter takes a graph signal and returns a filtered version by modifying
the spectral coefficients according to a frequency-response function h(λ).
Required Methods
Sourcefn apply(
&self,
gft: &GraphFourierTransform,
signal: &Array1<f64>,
) -> Result<Array1<f64>>
fn apply( &self, gft: &GraphFourierTransform, signal: &Array1<f64>, ) -> Result<Array1<f64>>
Apply the filter to signal using the precomputed GFT basis.
Sourcefn frequency_response(&self, gft: &GraphFourierTransform) -> Array1<f64>
fn frequency_response(&self, gft: &GraphFourierTransform) -> Array1<f64>
Return the frequency response h(λ) for each eigenvalue in gft.